==> scanbot_sdk-2.9.0.tar.gz: lib/classical_components/barcode_scanner_configuration.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_scanning_data.dart';

import 'camera_configuration.dart';

part 'barcode_scanner_configuration.g.dart';

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class BarcodeCameraConfiguration extends CameraConfiguration {
  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  ///Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  ///Default value is 0f.
  double? cameraZoomFactor;

  @override
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.barcode;

  FinderConfiguration? finder;

  BarcodeClassicScannerConfiguration scannerConfiguration;

  BarcodeCameraConfiguration({
    required this.scannerConfiguration,
    this.flashEnabled,
    this.finder,
    this.cameraZoomFactor,
  });

  @override
  Map<String, dynamic> toJson() => _$BarcodeCameraConfigurationToJson(this);
}

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class BarcodeClassicScannerConfiguration {
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.barcode;

  /// List of accepted Barcode Formats; any formats that are not included in this
  /// list will not be detected by the `BarcodeCameraView`. By default, the list
  /// includes all supported barcode types.
  List<BarcodeFormat> barcodeFormats;

  /// List of accepted Document Formats; any document formats that are not included
  /// in this list will be ignored by the `BarcodeCameraView`. By default, the list
  /// includes all supported document types.
  List<AcceptedDocumentFormats> acceptedDocumentFormats;

  /// The engine mode of the barcode recognizer. Defaults to NEXT_GEN.
  /// To use legacy recognizer, please specify LEGACY
  EngineMode? engineMode;

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType =
      BarcodeImageGenerationType.NONE;

  BarcodeClassicScannerConfiguration(
      {this.barcodeFormats = const [],
      this.acceptedDocumentFormats = const [],
      this.engineMode = EngineMode.NextGen,
      this.additionalParameters,
      this.barcodeImageGenerationType = BarcodeImageGenerationType.NONE});

  Map<String, dynamic> toJson() =>
      _$BarcodeClassicScannerConfigurationToJson(this);
}

==> scanbot_sdk-2.10.0.tar.gz: lib/classical_components/barcode_scanner_configuration.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_scanning_data.dart';

import '../json/common_data.dart';
import 'camera_configuration.dart';

part 'barcode_scanner_configuration.g.dart';

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class BarcodeCameraConfiguration extends CameraConfiguration {
  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  ///Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  ///Default value is 0f.
  double? cameraZoomFactor;

  @override
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.barcode;

  FinderConfiguration? finder;

  BarcodeClassicScannerConfiguration scannerConfiguration;

  BarcodeCameraConfiguration({
    required this.scannerConfiguration,
    this.flashEnabled,
    this.finder,
    this.cameraZoomFactor,
  });

  @override
  Map<String, dynamic> toJson() => _$BarcodeCameraConfigurationToJson(this);
}

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class BarcodeClassicScannerConfiguration {
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.barcode;

  /// List of accepted Barcode Formats; any formats that are not included in this
  /// list will not be detected by the `BarcodeCameraView`. By default, the list
  /// includes all supported barcode types.
  List<BarcodeFormat> barcodeFormats;

  /// List of accepted Document Formats; any document formats that are not included
  /// in this list will be ignored by the `BarcodeCameraView`. By default, the list
  /// includes all supported document types.
  List<BarcodeDocumentFormat> acceptedDocumentFormats;

  /// The engine mode of the barcode recognizer. Defaults to NEXT_GEN.
  /// To use legacy recognizer, please specify LEGACY
  EngineMode? engineMode;

  /// Additional parameters for tweaking the detection of barcodes.
  BarcodeAdditionalParameters? additionalParameters;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType =
      BarcodeImageGenerationType.NONE;

  BarcodeClassicScannerConfiguration(
      {this.barcodeFormats = const [],
      this.acceptedDocumentFormats = const [],
      this.engineMode = EngineMode.NextGen,
      this.additionalParameters,
      this.barcodeImageGenerationType = BarcodeImageGenerationType.NONE});

  Map<String, dynamic> toJson() =>
      _$BarcodeClassicScannerConfigurationToJson(this);
}
